=======
History
=======

0.1.0 (2018-06-15)
------------------

* First release on PyPI.

0.5.2 (2019-01-22)
------------------

* API for most modules is close to converged
* Significant number of bug fixes and new features
* Versioning system implemented through versioneer and bumpversion
* Automated pixel level tests for discovering effects of low-level changes
